@@ -147,8 +147,9 @@ class MetricsCalculator:
         return header + separator + "\n".join(rows)
 
 
-def save_pred_metrics(df: "DataFrame", pred_col: str, label_col: str, record_folder='record', config=None, prompt=None,
-                      font_path=None,
+def save_pred_metrics(df: "DataFrame", pred_col: str, label_col: str,
+                      record_folder='record', config=None, prompt=None, font_path=None,
+                      plot_confusion_matrix=False,
                       ):
     """ 保存预测结果的指标概览和分类报告 """
     metrics_calculator = MetricsCalculator(df, pred_col=pred_col, label_col=label_col)
@@ -172,15 +173,16 @@ def save_pred_metrics(df: "DataFrame", pred_col: str, label_col: str, record_fol
     with open(os.path.join(record_folder, 'metrics.md'), 'w', encoding='utf-8') as f:
         f.write(md)
 
-    try:
-        metrics_calculator.plot_confusion_matrix(
-            save_path=os.path.join(record_folder, 'confusion_matrix.png'),
-            font_path=font_path,
-            x_rotation=45,
-            y_rotation=0,
-        )
-    except Exception as e:
-        print(f"warning: Failed to plot confusion matrix: {e}")
+    if plot_confusion_matrix:
+        try:
+            metrics_calculator.plot_confusion_matrix(
+                save_path=os.path.join(record_folder, 'confusion_matrix.png'),
+                font_path=font_path,
+                x_rotation=45,
+                y_rotation=0,
+            )
+        except Exception as e:
+            print(f"warning: Failed to plot confusion matrix: {e}")
 
     if prompt:
         yaml_dump(os.path.join(record_folder, 'prompt.yaml'), prompt)
